Potvrde | OiRA
Description: Ovisno o pristupu koji primjenjuje nacionalni partner za alat OiRA ili programer alata OiRA, za svoju procjenu rizika možda ćete moći dobiti potvrdu. Obratite se svojem nacionalnom partneru za alat OiRA i zatražite pojedinosti o prednostima takvih potvrda.

Teme

# Potvrde

Ovisno o pristupu koji primjenjuje nacionalni partner za alat OiRA ili programer alata OiRA, za svoju procjenu rizika možda ćete moći dobiti potvrdu. Obratite se svojem nacionalnom partneru za alat OiRA i zatražite pojedinosti o prednostima takvih potvrda.

Kako možete dobiti potvrdu?

## Provedite potpunu procjenu rizika

Dok provodite procjenu rizika, u alatu OiRA bilježit će se vaš napredak. Nakon što procijenite niz rizika, u alatu ćete dobiti obavijest o tome da možete dobiti potvrdu o dovršetku potpune procjene rizika. Svaki nacionalni partner za alat OiRA ili programer alata OiRA postavlja prag (vrijednosti u postotcima) za definiranje „potpune” procjene rizika. Potvrda je dostupna klikom na gumb „Status” u izborniku s lijeve strane zaslona.

Na stranici sa statusom prikazuje se da je dostupna potvrda.

## Prikaz i objava vaše potvrde

Kad kliknete na gumb „Vidjeti potvrdu”, od vas će se tražiti da unesete ime poduzeća koji bi trebalo biti navedeno na potvrdi. Ovisno o nacionalnim postavkama, možda ćete trebati unijeti dodatne podatke kako bi na potvrdi bile navedene sve potrebne informacije.

Unesite sve potrebne informacije za potvrdu.

Ako označite okvir „Učini javno dostupnim”, prikazat će se jedinstvena poveznica (URL) na vašu potvrdu. Kopirajte tu poveznicu i podijelite je s relevantnim osobama kao dokaz da ste proveli procjenu rizika.

Napomena: Javno dostupni bit će isključivo podatci koji su prikazani na ovoj stranici. Ta poveznica nije dostupna u izborniku na mrežnom mjestu alata OiRA. Namijenjena je isključivo vama. Ipak, u teoriji bi svatko tko pretražuje internet mogao vidjeti potvrdu koju ste izradili.

U potvrdi se navodi samo da ste obradili određen broj rizika u alatu za procjenu rizika, ali se ne iznose nikakve dodatne informacije. Konkretne odgovore koje ste dali tijekom procjene rizika u alatu OiRA ne može vidjeti nitko osim vas.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More